//	Copyright  2000.	GSI Technology
//				Jeff Daugherty
//				jeffd@gsitechnology.com
//	Rev 1.0		Based on the GS816018 model
//      Rev 1.1         updated timing to match datasheet

`define		pipe
//`define     SP250MHZ
//`define     SP225MHZ
`define     SP200MHZ
//`define     SP166MHZ
//`define     SP150MHZ
//`define     SP133MHZ

`timescale 1ns / 100ps

module G8640E32T(A, DQa, DQb, DQc, DQd, nBW, nBa, nBb, nBc, nBd, 
			CK, nGW, nE1, E2, nE3, nG, nADV, nADSP, nADSC, ZZ, nFT, nLBO);


	parameter	ramtype		= 1,		// 1 burst
							// 2 NBT
							// 3 sigma
			ramversion	= 0,		// 0, 1, 2
			density 	= 64,		// 64M bit sram
			byteparl	= 4,		// 4 bytes in parallel
    			A_size 		= 21,		// +64M -4 bytes in parallel
			DQ_size 	= 8,
			bank_size 	= 1024*2048;	// *64M /4 bytes in parallel

	input	[A_size-1:0]		A; 		// address
	inout	[DQ_size-1:0]		DQa;		// byte A data
	inout	[DQ_size-1:0]		DQb;		// byte B data
	inout	[DQ_size-1:0]		DQc;		// byte C data
	inout	[DQ_size-1:0]		DQd;		// byte D data
	input				nBW;		// byte write enable
	input				nBa;		// bank A write enable
	input				nBb;		// bank B write enable
	input				nBc;		// bank C write enable
	input				nBd;		// bank D write enable
	input				CK;		// clock
	input				nGW;		// global write enable
	input				nE1;		// chip enable 1
	input				E2;		// chip enable 2
	input				nE3;		// chip enable 3
	input				nG;		// output enable
	input				nADV;		// Advance not / load
	input				nADSP;		// Address strobe (processor)
	input				nADSC;		// Address strobe (Cache CTL)
	input				ZZ;		// power down
	input				nFT;		// Pipeline / Flow through
	input				nLBO;		// Linear Burst Order not

	wire				nBe = 1,
					nBf = 1,
					nBg = 1,
					nBh = 1;
	wire    [8:0]			DQe,
					DQf,
					DQg,
					DQh;
	wire				DP;			// Even Data Parity
	wire				nQE;		// Parity Error
	wire				TMS;		// Scan Test Mode Select
	wire				TDI;		// Scan Test Data In
	wire				TDO;		// Scan Test Data Out
	wire				TCK;		// Scan Test Clock
	wire				SCD = 0;
	wire				nPE = 0;

//  state machine signals
	wire				gonew,
					gobur;

	assign				gonew = ~nE1 & E2 & ~nE3 & (~nADSC | ~nADSP);
	assign				gobur = (~nE1 | nADSP) & nADSC;
//  ******** Define Sram Operation Mode    ********************** 
	wire			NBT;		// NBT=1 activates NBT operation 
	wire			DDR;	 	// DDR=1 activates Double Data Rate
	assign			NBT = 0;
	assign			DDR = 0;

`ifdef SP250MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 2.5;

        specify
            specparam
    		tKC		= 4,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    		tS		= 1.2,	// setup time
    		tH		= 0.2;	// hold time
    `else
    		// flowthrough
    	parameter tKQ = 6.5;
    
        specify
            specparam
    		tKC		= 6.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
    `endif
`endif  // ------------------------------------------------------------------

`ifdef SP225MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
    	parameter tKQ = 2.7;
    
        specify
            specparam
    		tKC		= 4.4,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    		tS		= 1.3,	// setup time
    		tH		= 0.3;	// hold time
    `else
    		// flowthrough
	        parameter tKQ = 7.0;

        specify
            specparam
    		tKC		= 7.0	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
    `endif
`endif  // ------------------------------------------------------------------

`ifdef SP200MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 3.0;

        specify
            specparam
    		tKC		= 5,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    		tS		= 1.4,	// setup time
    		tH		= 0.4;	// hold time
    `else
    		// flowthrough
    	parameter tKQ = 7.5;
    
        specify
            specparam
    		tKC		= 7.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
    `endif
`endif  // ------------------------------------------------------------------

`ifdef SP166MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 3.4;

        specify
            specparam
    		tKC		= 6,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    `else
    		// flowthrough
    	parameter tKQ = 8.0;
    
        specify
            specparam
    		tKC		= 8.0,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    `endif
    		// common
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
`endif  // ------------------------------------------------------------------

`ifdef SP150MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 3.8;

        specify
            specparam
    		tKC		= 6.7,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    `else
    		// flowthrough
    	parameter tKQ = 8.5;
    
        specify
            specparam
    		tKC		= 8.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    `endif
    		// common
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
`endif  // ------------------------------------------------------------------

`ifdef SP133MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 4.0;

        specify
            specparam
    		tKC		= 7.5,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    `else
    		// flowthrough
    	parameter tKQ = 8.5;
    
        specify
            specparam
    		tKC		= 8.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    `endif
    		// common
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
`endif  // ------------------------------------------------------------------

        $setuphold  ( posedge CK, nBW,  tS, tH );  
        $setuphold  ( posedge CK, nBa,  tS, tH );  
        $setuphold  ( posedge CK, nBb,  tS, tH );  
        $setuphold  ( posedge CK, nBc,  tS, tH );  
        $setuphold  ( posedge CK, nBd,  tS, tH );  
        $setuphold  ( posedge CK, nADV,  tS, tH );  
        $setuphold  ( posedge CK, nGW,  tS, tH );  
        $setuphold  ( posedge CK, nE1,  tS, tH );  
        $setuphold  ( posedge CK, E2,   tS, tH );  
        $setuphold  ( posedge CK, nE3,  tS, tH );  
        $setuphold  ( posedge CK, nG,   tS, tH );  
        $setuphold  ( posedge CK, nADV, tS, tH );  
        $setuphold  ( posedge CK, nADSP,tS, tH );  
        $setuphold  ( posedge CK, nADSC,tS, tH );  
        $setuphold  ( posedge CK, nFT,  tS, tH );  
        $setuphold  ( posedge CK, nLBO, tS, tH );  
        $setuphold  ( posedge CK, DQd, tS, tH );    // Dq  
        $setuphold  ( posedge CK, DQc, tS, tH );    // Dq  
		endspecify


`include	"core.v"

endmodule



